<?php

namespace Drupal\livestorm\Event;

use Drupal\Component\Serialization\Json;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class LivestormWebhookSubscriber.
 *
 * Provides the event subscribers for 4 type of Livestorm webhook event.
 */
class LivestormWebhookSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events['livestorm.new_registrant'][] = ['logMessages'];
    $events['livestorm.webinar_start'][] = ['logMessages'];
    $events['livestorm.webinar_end'][] = ['logMessages'];
    $events['livestorm.webinar_published'][] = ['logMessages'];
    return $events;
  }

  /**
   * Write a webhook log message.
   *
   * @param \Drupal\livestorm\Event\LivestormWebhookEvent $event
   *   Livestorm event.
   */
  protected function logMessages(LivestormWebhookEvent $event) {
    \Drupal::logger('livestorm')
      ->notice('Processed webhook: @name<br /><br />Data: @data', [
        '@name' => $event->type,
        '@data' => Json::encode($event->data),
      ]);
  }

}
